@@ -122,6 +122,11 @@ extern const struct s2n_security_policy security_policy_20230317;
 extern const struct s2n_security_policy security_policy_20240331;
 extern const struct s2n_security_policy security_policy_20240417;
 extern const struct s2n_security_policy security_policy_20240416;
+extern const struct s2n_security_policy security_policy_20240603;
+extern const struct s2n_security_policy security_policy_20240730;
+extern const struct s2n_security_policy security_policy_20241001;
+extern const struct s2n_security_policy security_policy_20241001_pq_mixed;
+
 extern const struct s2n_security_policy security_policy_rfc9151;
 extern const struct s2n_security_policy security_policy_test_all;
 
@@ -147,6 +152,8 @@ extern const struct s2n_security_policy security_policy_aws_crt_sdk_ssl_v3;
 extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_10;
 extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_11;
 extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_12;
+extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_12_06_23;
+extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_12_06_23_pq;
 extern const struct s2n_security_policy security_policy_aws_crt_sdk_tls_13;
 
 extern const struct s2n_security_policy security_policy_kms_pq_tls_1_0_2019_06;
@@ -175,6 +182,10 @@ extern const struct s2n_security_policy security_policy_pq_tls_1_2_2023_10_07;
 extern const struct s2n_security_policy security_policy_pq_tls_1_2_2023_10_08;
 extern const struct s2n_security_policy security_policy_pq_tls_1_2_2023_10_09;
 extern const struct s2n_security_policy security_policy_pq_tls_1_2_2023_10_10;
+extern const struct s2n_security_policy security_policy_pq_tls_1_2_2024_10_07;
+extern const struct s2n_security_policy security_policy_pq_tls_1_2_2024_10_08;
+extern const struct s2n_security_policy security_policy_pq_tls_1_2_2024_10_08_gcm;
+extern const struct s2n_security_policy security_policy_pq_tls_1_2_2024_10_09;
 
 extern const struct s2n_security_policy security_policy_cloudfront_upstream;
 extern const struct s2n_security_policy security_policy_cloudfront_upstream_tls10;
@@ -192,6 +203,7 @@ extern const struct s2n_security_policy security_policy_cloudfront_tls_1_2_2021_
 extern const struct s2n_security_policy security_policy_kms_tls_1_0_2018_10;
 extern const struct s2n_security_policy security_policy_kms_tls_1_2_2023_06;
 extern const struct s2n_security_policy security_policy_kms_fips_tls_1_2_2018_10;
+extern const struct s2n_security_policy security_policy_kms_fips_tls_1_2_2024_10;
 
 extern const struct s2n_security_policy security_policy_20190120;
 extern const struct s2n_security_policy security_policy_20190121;
